# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimSubscriptionFragment


class TransferSubscription(BaseModel):
    transfer_subscription: "TransferSubscriptionTransferSubscription" = Field(
        alias="transferSubscription"
    )


class TransferSubscriptionTransferSubscription(SlimSubscriptionFragment):
    pass


TransferSubscription.update_forward_refs()
TransferSubscriptionTransferSubscription.update_forward_refs()



# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel


class MigrateSubscriptionToLatest(BaseModel):
    migrate_subscription_to_latest: "MigrateSubscriptionToLatestMigrateSubscriptionToLatest" = Field(
        alias="migrateSubscriptionToLatest"
    )


class MigrateSubscriptionToLatestMigrateSubscriptionToLatest(BaseModel):
    subscription_id: str = Field(alias="subscriptionId")


MigrateSubscriptionToLatest.update_forward_refs()
MigrateSubscriptionToLatestMigrateSubscriptionToLatest.update_forward_refs()



# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from .base_model import BaseModel
from .fragments import EntitlementFragment


class GetEntitlement(BaseModel):
    entitlement: "GetEntitlementEntitlement"


class GetEntitlementEntitlement(EntitlementFragment):
    pass


GetEntitlement.update_forward_refs()
GetEntitlementEntitlement.update_forward_refs()



# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import SlimCustomerFragment


class UnarchiveCustomer(BaseModel):
    unarchive_customer: "UnarchiveCustomerUnarchiveCustomer" = Field(
        alias="unarchiveCustomer"
    )


class UnarchiveCustomerUnarchiveCustomer(SlimCustomerFragment):
    pass


UnarchiveCustomer.update_forward_refs()
UnarchiveCustomerUnarchiveCustomer.update_forward_refs()



# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .fragments import CustomerStatisticsFragment


class GetCustomerStatistics(BaseModel):
    get_customer_by_ref_id: Optional["GetCustomerStatisticsGetCustomerByRefId"] = Field(
        alias="getCustomerByRefId"
    )


class GetCustomerStatisticsGetCustomerByRefId(CustomerStatisticsFragment):
    pass


GetCustomerStatistics.update_forward_refs()
GetCustomerStatisticsGetCustomerByRefId.update_forward_refs()



# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel


class CancelSubscriptionUpdates(BaseModel):
    cancel_schedule: str = Field(alias="cancelSchedule")


CancelSubscriptionUpdates.update_forward_refs()



# Generated by ariadne-codegen on 2024-01-31 14:49
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import ProvisionSubscriptionFragment


class ProvisionSubscription(BaseModel):
    provision_subscription: "ProvisionSubscriptionProvisionSubscription" = Field(
        alias="provisionSubscription"
    )


class ProvisionSubscriptionProvisionSubscription(ProvisionSubscriptionFragment):
    pass


ProvisionSubscription.update_forward_refs()
ProvisionSubscriptionProvisionSubscription.update_forward_refs()
